@@ -5,15 +5,15 @@ __all__ = [
     "__license__",
     "__summary__",
     "__title__",
-    "__url__",
+    "__uri__",
     "__version__",
 ]
 
 __title__ = "overpy"
 __summary__ = "Python Wrapper to access the OpenStreepMap Overpass API"
-__url__ = "https://github.com/DinoTools/python-overpy"
+__uri__ = "https://github.com/DinoTools/python-overpy"
 
-__version__ = "0.1"
+__version__ = "0.2.0"
 
 __author__ = "PhiBo (DinoTools)"
 __email__ = ""
